==> cobalt-0.0.1-sources.jar: it/auties/whatsapp/model/message/button/InteractiveMessageBuilder.java <==
package it.auties.whatsapp.model.message.button;

public class InteractiveMessageBuilder {
    private java.util.Optional<it.auties.whatsapp.model.button.interactive.InteractiveHeader> header;
    private java.util.Optional<it.auties.whatsapp.model.button.interactive.InteractiveBody> body;
    private java.util.Optional<it.auties.whatsapp.model.button.interactive.InteractiveFooter> footer;
    private java.util.Optional<it.auties.whatsapp.model.button.interactive.InteractiveShop> contentShop;
    private java.util.Optional<it.auties.whatsapp.model.button.interactive.InteractiveCollection> contentCollection;
    private java.util.Optional<it.auties.whatsapp.model.button.interactive.InteractiveNativeFlow> contentNativeFlow;
    private java.util.Optional<it.auties.whatsapp.model.info.ContextInfo> contextInfo;

    public InteractiveMessageBuilder() {
        header = java.util.Optional.empty();
        body = java.util.Optional.empty();
        footer = java.util.Optional.empty();
        contentShop = java.util.Optional.empty();
        contentCollection = java.util.Optional.empty();
        contentNativeFlow = java.util.Optional.empty();
        contextInfo = java.util.Optional.empty();
    }

    public InteractiveMessageBuilder header(java.util.Optional<it.auties.whatsapp.model.button.interactive.InteractiveHeader> header) {
        this.header = header;
        return this;
    }
    public InteractiveMessageBuilder header(it.auties.whatsapp.model.button.interactive.InteractiveHeader header) {
        this.header = java.util.Optional.ofNullable(header);
        return this;
    }
    public InteractiveMessageBuilder body(java.util.Optional<it.auties.whatsapp.model.button.interactive.InteractiveBody> body) {
        this.body = body;
        return this;
    }
    public InteractiveMessageBuilder body(it.auties.whatsapp.model.button.interactive.InteractiveBody body) {
        this.body = java.util.Optional.ofNullable(body);
        return this;
    }
    public InteractiveMessageBuilder footer(java.util.Optional<it.auties.whatsapp.model.button.interactive.InteractiveFooter> footer) {
        this.footer = footer;
        return this;
    }
    public InteractiveMessageBuilder footer(it.auties.whatsapp.model.button.interactive.InteractiveFooter footer) {
        this.footer = java.util.Optional.ofNullable(footer);
        return this;
    }
    public InteractiveMessageBuilder contentShop(java.util.Optional<it.auties.whatsapp.model.button.interactive.InteractiveShop> contentShop) {
        this.contentShop = contentShop;
        return this;
    }
    public InteractiveMessageBuilder contentShop(it.auties.whatsapp.model.button.interactive.InteractiveShop contentShop) {
        this.contentShop = java.util.Optional.ofNullable(contentShop);
        return this;
    }
    public InteractiveMessageBuilder contentCollection(java.util.Optional<it.auties.whatsapp.model.button.interactive.InteractiveCollection> contentCollection) {
        this.contentCollection = contentCollection;
        return this;
    }
    public InteractiveMessageBuilder contentCollection(it.auties.whatsapp.model.button.interactive.InteractiveCollection contentCollection) {
        this.contentCollection = java.util.Optional.ofNullable(contentCollection);
        return this;
    }
    public InteractiveMessageBuilder contentNativeFlow(java.util.Optional<it.auties.whatsapp.model.button.interactive.InteractiveNativeFlow> contentNativeFlow) {
        this.contentNativeFlow = contentNativeFlow;
        return this;
    }
    public InteractiveMessageBuilder contentNativeFlow(it.auties.whatsapp.model.button.interactive.InteractiveNativeFlow contentNativeFlow) {
        this.contentNativeFlow = java.util.Optional.ofNullable(contentNativeFlow);
        return this;
    }
    public InteractiveMessageBuilder contextInfo(java.util.Optional<it.auties.whatsapp.model.info.ContextInfo> contextInfo) {
        this.contextInfo = contextInfo;
        return this;
    }
    public InteractiveMessageBuilder contextInfo(it.auties.whatsapp.model.info.ContextInfo contextInfo) {
        this.contextInfo = java.util.Optional.ofNullable(contextInfo);
        return this;
    }

    public it.auties.whatsapp.model.message.button.InteractiveMessage build() {
        return new it.auties.whatsapp.model.message.button.InteractiveMessage(header, body, footer, contentShop, contentCollection, contentNativeFlow, contextInfo);
    }
}

==> cobalt-0.0.3-sources.jar: it/auties/whatsapp/model/message/button/InteractiveMessageBuilder.java <==
package it.auties.whatsapp.model.message.button;

public class InteractiveMessageBuilder {
    private it.auties.whatsapp.model.button.interactive.InteractiveHeader header;
    private it.auties.whatsapp.model.button.interactive.InteractiveBody body;
    private it.auties.whatsapp.model.button.interactive.InteractiveFooter footer;
    private it.auties.whatsapp.model.button.interactive.InteractiveShop contentShop;
    private it.auties.whatsapp.model.button.interactive.InteractiveCollection contentCollection;
    private it.auties.whatsapp.model.button.interactive.InteractiveNativeFlow contentNativeFlow;
    private it.auties.whatsapp.model.info.ContextInfo contextInfo;

    public InteractiveMessageBuilder() {
        header = null;
        body = null;
        footer = null;
        contentShop = null;
        contentCollection = null;
        contentNativeFlow = null;
        contextInfo = null;
    }

    public InteractiveMessageBuilder header(it.auties.whatsapp.model.button.interactive.InteractiveHeader header) {
        this.header = header;
        return this;
    }
    public InteractiveMessageBuilder body(it.auties.whatsapp.model.button.interactive.InteractiveBody body) {
        this.body = body;
        return this;
    }
    public InteractiveMessageBuilder footer(it.auties.whatsapp.model.button.interactive.InteractiveFooter footer) {
        this.footer = footer;
        return this;
    }
    public InteractiveMessageBuilder contentShop(it.auties.whatsapp.model.button.interactive.InteractiveShop contentShop) {
        this.contentShop = contentShop;
        return this;
    }
    public InteractiveMessageBuilder contentCollection(it.auties.whatsapp.model.button.interactive.InteractiveCollection contentCollection) {
        this.contentCollection = contentCollection;
        return this;
    }
    public InteractiveMessageBuilder contentNativeFlow(it.auties.whatsapp.model.button.interactive.InteractiveNativeFlow contentNativeFlow) {
        this.contentNativeFlow = contentNativeFlow;
        return this;
    }
    public InteractiveMessageBuilder contextInfo(it.auties.whatsapp.model.info.ContextInfo contextInfo) {
        this.contextInfo = contextInfo;
        return this;
    }

    public it.auties.whatsapp.model.message.button.InteractiveMessage build() {
        return new it.auties.whatsapp.model.message.button.InteractiveMessage(header, body, footer, contentShop, contentCollection, contentNativeFlow, contextInfo);
    }
}
